% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lute_randomized-data.R
\name{randomMarkersVectorsList}
\alias{randomMarkersVectorsList}
\title{randomMarkersVectorsList}
\usage{
randomMarkersVectorsList(
  markerIndexVector,
  numberIterations = 1,
  lambdaMean = 25,
  lambdaMeanNegative = 2,
  method = "nbinom",
  gammaSize = 10,
  gammaSizeNegative = 10
)
}
\arguments{
\item{markerIndexVector}{Vector of marker indices. Index values correspond to the k types,
and each index position represents a marker (e.g. c(1,2,2) means two markers 
for the second type, etc.).}

\item{numberIterations}{Total simulation iterations.}

\item{lambdaMean}{Value of lambda (Poisson dist. mean) for "positive" marker 
status (e.g. mean of dist. for k when marker is positive for k, negative for 
not-k). This is passed to the argument mu when method is "nbinom".}

\item{lambdaMeanNegative}{Value of lambda (Poisson dist. mean) for "negative" marker 
status (e.g. mean of dist. for k when marker is positive for not-k, negative 
for k). This is passed to the argument mu when method is "nbinom".}

\item{method}{Type of randomization method to use. Accepts either "poisson"
for poisson distribution (see `?rpois` for details), or "nbinom" for the 
negative binomial (a.k.a. gamm poisson) distribution (see `?rnbinom` for 
details).}

\item{gammaSize}{The gamma distribution magnitude for "positive" markers. 
This is applied when the "nbinom" method is used.}

\item{gammaSizeNegative}{The gamma distribution magnitude for "negative" markers. 
This is applied when the "nbinom" method is used.}
}
\value{
Listed lgv object containing the randomized marker values across 
types.
}
\description{
Get randomized markers using Poisson distribution sampling. For a given K,
we assume "positive" markers have higher values than for non-K types, and 
thus we sample from 2 different Poisson distributions defined by different
lambda values (e.g. arguments lambdaMean, lambdaMeanNegative). WE also use argument 
markerIndexVector to define total markers as length(markerIndexVector) and the marker balance as
relative counts of each type index.
}
\details{
For example, if gindex is c(1, 1, 2), we define 3 total markers, 2 positive
markers for type 1 (negative for type 2) and a single positive marker for 
type 2 (negative for type 1).
}
\examples{
randomMarkersVectorsList(markerIndexVector=c(rep(1, 10), rep(2, 5)))

}
